Index: third_party/WebKit/Source/core/html/shadow/TextControlInnerElements.cpp |
diff --git a/third_party/WebKit/Source/core/html/shadow/TextControlInnerElements.cpp b/third_party/WebKit/Source/core/html/shadow/TextControlInnerElements.cpp |
index 642fb0227372f9018f2e544a8c7460d4125f45dc..daac9bbd5f7c4b8fff320bf7c658d86b1a75aece 100644 |
--- a/third_party/WebKit/Source/core/html/shadow/TextControlInnerElements.cpp |
+++ b/third_party/WebKit/Source/core/html/shadow/TextControlInnerElements.cpp |
@@ -94,6 +94,9 @@ PassRefPtr<ComputedStyle> EditingViewPortElement::customStyleForLayoutObject() |
style->setUserModify(READ_ONLY); |
style->setUnique(); |
+ if (const ComputedStyle* parentStyle = parentComputedStyle()) |
+ StyleAdjuster::adjustStyleForAlignment(*style, *parentStyle); |
+ |
return style.release(); |
} |
@@ -144,8 +147,10 @@ PassRefPtr<ComputedStyle> TextControlInnerEditorElement::customStyleForLayoutObj |
LayoutTextControlItem textControlLayoutItem = LayoutTextControlItem(toLayoutTextControl(parentLayoutObject)); |
RefPtr<ComputedStyle> innerEditorStyle = textControlLayoutItem.createInnerEditorStyle(textControlLayoutItem.styleRef()); |
// Using StyleAdjuster::adjustComputedStyle updates unwanted style. We'd like |
// to apply only editing-related. |
StyleAdjuster::adjustStyleForEditing(*innerEditorStyle); |
+ if (const ComputedStyle* parentStyle = parentComputedStyle()) |
+ StyleAdjuster::adjustStyleForAlignment(*innerEditorStyle, *parentStyle); |
return innerEditorStyle.release(); |
} |
@@ -144,8 +147,10 @@ PassRefPtr<ComputedStyle> TextControlInnerEditorElement::customStyleForLayoutObj |
RefPtr<ComputedStyle> innerEditorStyle = textControlLayoutItem.createInnerEditorStyle(textControlLayoutItem.styleRef()); |
// Using StyleAdjuster::adjustComputedStyle updates unwanted style. We'd like |
- // to apply only editing-related. |
+ // to apply only editing-related and alignment-related. |
StyleAdjuster::adjustStyleForEditing(*innerEditorStyle); |